==> gnome-system-tools-0.22.0.tar.bz2: gnome-system-tools-0.22.0/interfaces/boot.glade.h <==
/*
 * Archivo de cadenas traducibles generado por Glade.
 * Añada este archivo a su POTFILES.in de su proyecto.
 * NO lo compile como parte de su aplicación.
 */

gchar *s = N_("Use this tool to set the installed operating\n"
              "systems to choose from at startup.");
gchar *s = N_("_Add...");
gchar *s = N_("_Delete");
gchar *s = N_("_Edit...");
gchar *s = N_("_Wait");
gchar *s = N_("Wait");
gchar *s = N_("_seconds before loading default kernel or OS");
gchar *s = N_("Starting your computer");
gchar *s = N_("Modify the settings for an operating system or kernel.");
gchar *s = N_("_Name:");
gchar *s = N_("Boot _type:");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("Basic");
gchar *s = N_("_Path:");
gchar *s = N_("*");
gchar *s = N_("_Root:");
gchar *s = N_("*");
gchar *s = N_("_Append:");
gchar *s = N_("*");
gchar *s = N_("Image");
gchar *s = N_("_Device:");
gchar *s = N_("*");
gchar *s = N_("Other");
gchar *s = N_("Boot Image Assistant");
gchar *s = N_("Boot Image Assistant");
gchar *s = N_("This assistant is designed to help you quickly \n"
              "and easily add new boot images to your system.\n"
              "\n"
              "To begin, click \"Next\". ");
gchar *s = N_("Image Identity (step 1 of 2)");
gchar *s = N_("Enter a name for the boot image, and specify what kind of operating system it is.");
gchar *s = N_("Click \"Next\" to continue");
gchar *s = N_("Other  (step 2 of 2)");
gchar *s = N_("Specify the partition on which the operating system is installed.");
gchar *s = N_("Click \"Next\" to continue");
gchar *s = N_("Image (step 2 of 2)");
gchar *s = N_("Choose a kernel image to boot, and a partition to mount as the root partition.\n"
              "Optionally, you may also enter append parameters which are passed to the\n"
              "kernel at boot time.");
gchar *s = N_("Click \"Next\" to continue");
gchar *s = N_("Finished");
gchar *s = N_("The new boot image has been added.\n"
              "Please click \"Finish\" to save your changes. ");

==> gnome-system-tools-0.23.0.tar.bz2: gnome-system-tools-0.23.0/interfaces/boot.glade.h <==
/*
 * Archivo de cadenas traducibles generado por Glade.
 * Añada este archivo a su POTFILES.in de su proyecto.
 * NO lo compile como parte de su aplicación.
 */

gchar *s = N_("Use this tool to set the installed operating\n"
              "systems to choose from at startup.");
gchar *s = N_("_Add...");
gchar *s = N_("_Delete");
gchar *s = N_("_Edit...");
gchar *s = N_("<span weight=\"bold\">Starting your computer</span>");
gchar *s = N_("Seconds to wait before loading default kernel or OS");
gchar *s = N_("Modify the settings for an operating system or kernel.");
gchar *s = N_("<span weight=\"bold\">Basic</span>");
gchar *s = N_("_Name:");
gchar *s = N_("Boot _type:");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("_Path:");
gchar *s = N_("_Root:");
gchar *s = N_("_Append:");
gchar *s = N_("*");
gchar *s = N_("<span weight=\"bold\">Image</span>");
gchar *s = N_("*");
gchar *s = N_("*");
gchar *s = N_("_Edit parameters");
gchar *s = N_("<span weight=\"bold\">Other</span>");
gchar *s = N_("_Device:");
gchar *s = N_("*");
gchar *s = N_("Boot Image Assistant");
gchar *s = N_("Boot Image Assistant");
gchar *s = N_("This assistant is designed to help you quickly \n"
              "and easily add new boot images to your system.\n"
              "\n"
              "To begin, click \"Next\". ");
gchar *s = N_("Image Identity (step 1 of 2)");
gchar *s = N_("Enter a name for the boot image, and specify what kind of operating system it is.");
gchar *s = N_("Click \"Next\" to continue");
gchar *s = N_("Other  (step 2 of 2)");
gchar *s = N_("Specify the partition on which the operating system is installed.");
gchar *s = N_("Click \"Next\" to continue");
gchar *s = N_("Image (step 2 of 2)");
gchar *s = N_("Choose a kernel image to boot, and a partition to mount as the root partition.\n"
              "Optionally, you may also enter append parameters which are passed to the\n"
              "kernel at boot time.");
gchar *s = N_("Click \"Next\" to continue");
gchar *s = N_("Finished");
gchar *s = N_("The new boot image has been added.\n"
              "Please click \"Finish\" to save your changes. ");
gchar *s = N_("Usual kernel parameters");
gchar *s = N_("Manual");
gchar *s = N_("256");
gchar *s = N_("32K");
gchar *s = N_("64K");
gchar *s = N_("16M");
gchar *s = N_("Number of colours");
gchar *s = N_("640x480");
gchar *s = N_("800x600");
gchar *s = N_("1024x768");
gchar *s = N_("1280x1024");
gchar *s = N_("Resolution");
gchar *s = N_("Ask at boot");
gchar *s = N_("Video modes (only framebuffer)");
gchar *s = N_("Scsi emulation devices");
gchar *s = N_("/dev/hdb");
gchar *s = N_("/dev/hdd");
gchar *s = N_("/dev/hdc");
gchar *s = N_("/dev/hda");
gchar *s = N_("Other options");
gchar *s = N_("*");
